/*
    See the JupyterLab Developer Guide for useful CSS Patterns:

    https://jupyterlab.readthedocs.io/en/stable/developer/css.html
*/

.jp-Splash {
  background-color: #37485a;
  animation: none !important;
  display: none !important;
}

.jp-Splash .jp-Splash-logos {
  display: none !important;
  animation: none !important;
}
